@@ -2,7 +2,7 @@
 
 /*
  * EggPlayPreview GTK+ Widget - egg-play-preview.c
- * 
+ *
  * Copyright (C) 2008 Luca Cavalli <luca.cavalli@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -122,7 +122,7 @@ static void _stop                            (EggPlayPreview *play_preview);
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (EggPlayPreview, egg_play_preview, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (EggPlayPreview, egg_play_preview, GTK_TYPE_BOX)
 
 static void
 egg_play_preview_class_init (EggPlayPreviewClass *klass)
@@ -255,7 +255,7 @@ egg_play_preview_init (EggPlayPreview *play_preview)
 	gtk_box_set_spacing (GTK_BOX (play_preview), 6);
 
 	/* track info */
-	vbox = gtk_vbox_new (TRUE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	priv->title_label = gtk_label_new (NULL);
 	gtk_label_set_justify (GTK_LABEL (priv->title_label), GTK_JUSTIFY_LEFT);
@@ -274,7 +274,7 @@ egg_play_preview_init (EggPlayPreview *play_preview)
 	gtk_misc_set_alignment (GTK_MISC (priv->artist_album_label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->artist_album_label, TRUE, TRUE, 0);
 
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 
 	/* play button */
 	priv->play_button = gtk_button_new ();
@@ -284,7 +284,7 @@ egg_play_preview_init (EggPlayPreview *play_preview)
 	gtk_container_add (GTK_CONTAINER (align), priv->play_button);
 
 	/* time scale */
-	priv->time_scale = gtk_hscale_new_with_range (0.0, 100.0, 1.0);
+	priv->time_scale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0.0, 100.0, 1.0);
 	gtk_scale_set_draw_value (GTK_SCALE (priv->time_scale), FALSE);
 	gtk_widget_set_size_request (priv->time_scale, EGG_PLAYER_PREVIEW_WIDTH, -1);
 	priv->time_label = gtk_label_new ("0:00");
@@ -374,7 +374,7 @@ egg_play_preview_set_property (GObject       *object,
     }
 }
 
-static void 
+static void
 egg_play_preview_get_property (GObject     *object,
 							   guint        prop_id,
 							   GValue      *value,
@@ -518,8 +518,8 @@ static void
 _setup_pipeline (EggPlayPreview *play_preview)
 {
 	EggPlayPreviewPrivate *priv;
-	GstElement *audiosink;
 	GstBus *bus = NULL;
+        guint flags;
 
 	priv = GET_PRIVATE (play_preview);
 
@@ -529,21 +529,14 @@ _setup_pipeline (EggPlayPreview *play_preview)
 	if (!priv->playbin)
 		return;
 
-	audiosink = gst_element_factory_make ("gconfaudiosink", "audiosink");
-	if (!audiosink) {
-		audiosink = gst_element_factory_make ("autoaudiosink", "audiosink");
-		if (!audiosink) {
-			audiosink = gst_element_factory_make ("alsasink", "audiosink");
-			if (!audiosink) {
-				return;
-			}
-		}
-	}
-
+        /* Disable video output */
+        g_object_get (G_OBJECT (priv->playbin),
+                      "flags", &flags,
+                      NULL);
+        flags &= ~0x00000001;
 	g_object_set (G_OBJECT (priv->playbin),
-				  "audio-sink", audiosink,
-				  "video-sink", NULL,
-				  NULL);
+                      "flags", flags,
+                      NULL);
 
 	bus = gst_pipeline_get_bus (GST_PIPELINE (priv->playbin));
 	gst_bus_add_watch (bus, (GstBusFunc) _process_bus_messages, play_preview);
@@ -566,7 +559,7 @@ _clear_pipeline (EggPlayPreview *play_preview)
 		gst_object_unref (bus);
 
 		gst_element_set_state (priv->playbin, GST_STATE_NULL);
-        gst_object_unref (GST_OBJECT (priv->playbin));
+                gst_object_unref (GST_OBJECT (priv->playbin));
 		priv->playbin = NULL;
 	}
 }
@@ -684,10 +677,8 @@ _query_duration (GstElement *element)
 	GstState state;
 	GstState pending;
 	gint64 duration;
-	GstFormat format;
 
 	duration = 0;
-	format = GST_FORMAT_TIME;
 
 	result = gst_element_get_state (element, &state, &pending, GST_CLOCK_TIME_NONE);
 
@@ -702,7 +693,7 @@ _query_duration (GstElement *element)
 	if (result == GST_STATE_CHANGE_ASYNC)
 		gst_element_get_state (element, NULL, NULL, GST_CLOCK_TIME_NONE);
 
-	gst_element_query_duration (element, &format, &duration);
+	gst_element_query_duration (element, GST_FORMAT_TIME, &duration);
 
 	gst_element_set_state (element, state);
 
@@ -713,12 +704,10 @@ static gint
 _query_position (GstElement *element)
 {
 	gint64 position;
-	GstFormat format;
 
 	position = 0;
-	format = GST_FORMAT_TIME;
 
-	gst_element_query_position (element, &format, &position);
+	gst_element_query_position (element, GST_FORMAT_TIME, &position);
 
 	return (gint) (position / GST_SECOND);
 }
