@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (C) 2003 Ross Burton <ross@burtonini.com>
  *
  * Sound Juicer - sj-extracting.c
@@ -195,12 +195,12 @@ find_next (void)
 {
   do {
     gboolean extract = FALSE;
-    
+
     gtk_tree_model_get (GTK_TREE_MODEL (track_store), &current, COLUMN_EXTRACT, &extract, -1);
-    
+
     if (extract)
       return TRUE;
-    
+
   } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (track_store), &current));
   return FALSE;
 }
@@ -235,26 +235,26 @@ cleanup (void)
   /* TODO: find out why GTK+ needs this to work (see #364371) */
   gtk_button_set_label (GTK_BUTTON (extract_button), _("Extract"));
   gtk_button_set_label (GTK_BUTTON (extract_button), SJ_STOCK_EXTRACT);
-  
+
   /* Clear the Status bar */
   gtk_statusbar_push (GTK_STATUSBAR (status_bar), 0, "");
   /* Clear the progress bar */
   gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar), 0);
   gtk_widget_hide (progress_bar);
-  
+
   gtk_widget_set_sensitive (play_button, TRUE);
   gtk_widget_set_sensitive (title_entry, TRUE);
   gtk_widget_set_sensitive (artist_entry, TRUE);
   gtk_widget_set_sensitive (genre_entry, TRUE);
   gtk_widget_set_sensitive (year_entry, TRUE);
   gtk_widget_set_sensitive (disc_number_entry, TRUE);
-  /* Enabling the Menuitem */ 
+  /* Enabling the Menuitem */
   gtk_widget_set_sensitive (play_menuitem, TRUE);
   gtk_widget_set_sensitive (extract_menuitem, TRUE);
   gtk_widget_set_sensitive (reread_menuitem, TRUE);
   gtk_widget_set_sensitive (select_all_menuitem, TRUE);
   gtk_widget_set_sensitive (deselect_all_menuitem, TRUE);
-  
+
   /*Enable the Extract column and Make the Title and Artist column Editable*/
   g_object_set (G_OBJECT (toggle_renderer), "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, NULL);
   g_object_set (G_OBJECT (title_renderer), "editable", TRUE, NULL);
@@ -273,7 +273,7 @@ check_file_size (GFile *uri)
   GFileInfo *gfile_info;
   GError *error = NULL;
   goffset size;
- 
+
   gfile_info = g_file_query_info (uri, G_FILE_ATTRIBUTE_STANDARD_SIZE, 0,
                                   NULL, &error);
 
@@ -299,14 +299,18 @@ check_file_size (GFile *uri)
 
 static gboolean
 confirm_overwrite_existing_file (GFile *uri, int *overwrite_mode, goffset info_size)
-{ 
+{
   OverwriteDialogResponse ret;
   GtkWidget *dialog;
   GtkWidget *play_preview;
   char *display_name, *filename, *size;
 
   display_name = g_file_get_parse_name (uri);
-  size = g_format_size_for_display (info_size);
+#if GLIB_CHECK_VERSION(2,30,0)
+  size = g_format_size (info_size);
+#else
+  size = g_format_size_for_display(info_size);
+#endif
   dialog = gtk_message_dialog_new (GTK_WINDOW (main_window), GTK_DIALOG_MODAL,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_NONE,
@@ -457,13 +461,13 @@ pop_and_extract (int *overwrite_mode)
     /* Update the state stock image */
     gtk_list_store_set (track_store, &current,
                    COLUMN_STATE, STATE_EXTRACTING, -1);
-    
+
     /* Update the progress bars */
     gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar),
                                    CLAMP ((float)current_duration / (float)total_duration, 0.0, 1.0));
 
     /* Set the Treelist focus to the item to be extracted */
-    GtkTreePath* path = gtk_tree_model_get_path(GTK_TREE_MODEL (track_store), &current); 
+    GtkTreePath* path = gtk_tree_model_get_path(GTK_TREE_MODEL (track_store), &current);
     gtk_tree_view_set_cursor(GTK_TREE_VIEW (track_listview), path, NULL, TRUE);
     gtk_tree_path_free(path);
 
@@ -472,7 +476,7 @@ pop_and_extract (int *overwrite_mode)
     if (error) {
       goto error;
     } else
-        successful_extract = TRUE;       
+        successful_extract = TRUE;
     goto local_cleanup;
 error:
     successful_extract = FALSE;
@@ -514,11 +518,11 @@ update_speed_progress (SjExtractor *extractor, float speed, int eta)
   char *eta_str;
 
   if (eta >= 0) {
-    eta_str = g_strdup_printf (_("Estimated time left: %d:%02d (at %0.1f\303\227)"), eta / 60, eta % 60, speed);  
+    eta_str = g_strdup_printf (_("Estimated time left: %d:%02d (at %0.1f\303\227)"), eta / 60, eta % 60, speed);
   } else {
-    eta_str = g_strdup (_("Estimated time left: unknown"));  
+    eta_str = g_strdup (_("Estimated time left: unknown"));
   }
-  
+
   gtk_statusbar_push (GTK_STATUSBAR (status_bar), 0, eta_str);
   g_free (eta_str);
 }
@@ -545,7 +549,7 @@ on_progress_cb (SjExtractor *extractor, const int seconds, gpointer data)
 
       gettimeofday(&time, NULL);
       taken = time.tv_sec + (time.tv_usec / 1000000.0)
-        - (before.time.tv_sec + (before.time.tv_usec / 1000000.0)); 
+        - (before.time.tv_sec + (before.time.tv_usec / 1000000.0));
       if (taken >= 4) {
         before.taken += taken;
         before.ripped += current_duration + seconds - before.seconds;
@@ -608,7 +612,7 @@ finished_actions (void)
     CA_PROP_EVENT_ID, "complete-media-rip",
     CA_PROP_EVENT_DESCRIPTION, _("CD rip complete"),
     NULL);
-  
+
   /* Trigger glowing effect after copy */
   g_signal_connect (G_OBJECT (main_window), "focus-in-event",
                     G_CALLBACK (on_main_window_focus_in),  NULL);
@@ -618,7 +622,7 @@ finished_actions (void)
   if (eject_finished && successful_extract) {
     brasero_drive_eject (drive, FALSE, NULL);
   }
-  
+
   /* Maybe open the target directory */
   if (open_finished) {
     char *base = NULL;
@@ -650,7 +654,7 @@ on_completion_cb (SjExtractor *extractor, gpointer data)
     /* Uncheck the Extract check box */
     gtk_list_store_set (track_store, &current, COLUMN_EXTRACT, FALSE, -1);
   }
-  
+
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &current,
                       COLUMN_DETAILS, &track, -1);
 
@@ -664,7 +668,7 @@ on_completion_cb (SjExtractor *extractor, gpointer data)
 
     g_object_unref (temp_file);
     g_object_unref (new_file);
-    
+
   if (error) {
     on_error_cb (NULL, error, NULL);
     g_error_free (error);
@@ -720,7 +724,7 @@ on_progress_cancel_clicked (GtkWidget *button, gpointer user_data)
   GError *error = NULL;
 
   sj_extractor_cancel_extract (extractor);
-  
+
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), &current,
                       COLUMN_DETAILS, &track, -1);
 
@@ -743,16 +747,16 @@ G_MODULE_EXPORT void
 on_extract_activate (GtkWidget *button, gpointer user_data)
 {
   char *reason;
-  
+
   /* first make sure we're not playing, we cannot share the resource */
   stop_playback ();
-  
+
   /* If extracting, then cancel the extract */
   if (extracting) {
      on_progress_cancel_clicked (NULL, NULL);
      return;
   }
-        
+
   /* Populate the pending list */
   current.stamp = 0;
   total_extracting = 0;
@@ -784,22 +788,22 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
     track_listview    = GET_WIDGET ("track_listview");
     progress_bar      = GET_WIDGET ("progress_bar");
     status_bar        = GET_WIDGET ("status_bar");
-  
+
     play_menuitem         = GET_WIDGET ("play_menuitem");
     extract_menuitem      = GET_WIDGET ("extract_menuitem");
     reread_menuitem       = GET_WIDGET ("re-read");
     select_all_menuitem   = GET_WIDGET ("select_all");
     deselect_all_menuitem = GET_WIDGET ("deselect_all");
-    
+
     initialised = TRUE;
   }
-  
+
   /* Change the label to Stop while extracting*/
   /* TODO: find out why GTK+ needs this to work (see #364371) */
   gtk_button_set_label (GTK_BUTTON (extract_button), _("Stop"));
   gtk_button_set_label (GTK_BUTTON (extract_button), GTK_STOCK_STOP);
   gtk_widget_show (progress_bar);
-  
+
   /* Reset the progress dialog */
   gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar), 0);
   update_speed_progress (NULL, 0.0, -1);
@@ -812,13 +816,13 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
   gtk_widget_set_sensitive (year_entry, FALSE);
   gtk_widget_set_sensitive (disc_number_entry, FALSE);
 
-  /* Disable the menuitems in the main menu*/ 
+  /* Disable the menuitems in the main menu*/
   gtk_widget_set_sensitive (play_menuitem, FALSE);
   gtk_widget_set_sensitive (extract_menuitem, FALSE);
   gtk_widget_set_sensitive (reread_menuitem, FALSE);
   gtk_widget_set_sensitive (select_all_menuitem, FALSE);
   gtk_widget_set_sensitive (deselect_all_menuitem, FALSE);
-  
+
   /* Disable the Extract column */
   g_object_set (G_OBJECT (toggle_renderer), "mode", GTK_CELL_RENDERER_MODE_INERT, NULL);
   g_object_set (G_OBJECT (title_renderer), "editable", FALSE, NULL);
@@ -829,7 +833,7 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
     g_warning ("Could not lock drive: %s", reason);
     g_free (reason);
   }
-  
+
   cookie = sj_inhibit (g_get_application_name (),
                        _("Extracting audio from CD"),
                        GDK_WINDOW_XID(gtk_widget_get_window (main_window)));
@@ -856,7 +860,7 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
  * shell-friendly. This involves removing [?*\ ] and replacing with '_'.  Also
  * any leading periods are removed so that the files don't end up being hidden.
  *
- * This function doesn't change the input, and returns an allocated 
+ * This function doesn't change the input, and returns an allocated
  * string.
  */
 static char*
@@ -868,11 +872,11 @@ sanitize_path (const char* str, const char* filesystem_type)
   /* Skip leading periods, otherwise files disappear... */
   while (*str == '.')
     str++;
-  
+
   s = g_strdup(str);
   /* Replace path seperators with a hyphen */
   g_strdelimit (s, "/", '-');
-  
+
   /* filesystem specific sanitizing */
   if (filesystem_type) {
     if ((strcmp (filesystem_type, "vfat") == 0) ||
@@ -880,7 +884,7 @@ sanitize_path (const char* str, const char* filesystem_type)
       g_strdelimit (s, "\\:*?\"<>|", ' ');
     }
   }
-    
+
   if (strip_chars) {
     /* Replace separators with a hyphen */
     g_strdelimit (s, "\\:|", '-');
@@ -928,7 +932,7 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
 
   if (pattern == NULL || pattern[0] == 0)
     return g_strdup (" ");
-  
+
   fs_info = g_file_query_filesystem_info (base_uri, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE,
                                           NULL, NULL);
   if (fs_info) {
@@ -973,7 +977,7 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
         break;
       case 'y':
         if (track->album->release_date && g_date_valid(track->album->release_date)) {
-          tmp = g_strdup_printf ("%d", g_date_get_year (track->album->release_date)); 
+          tmp = g_strdup_printf ("%d", g_date_get_year (track->album->release_date));
           string = sanitize_path (tmp, filesystem_type);
           g_free (tmp);
         }
@@ -1080,7 +1084,7 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
       default:
         g_string_append (s, "%d");
         p += 2;
-        
+
         g_string_append_unichar (s, g_utf8_get_char (p));
         p = g_utf8_next_char (p);
         go_next = FALSE;
@@ -1102,8 +1106,8 @@ filepath_parse_pattern (const char* pattern, const TrackDetails *track)
     if (go_next)
       ++p;
   }
-  
-  g_free (filesystem_type); 
+
+  g_free (filesystem_type);
 
   str = s->str;
   g_string_free (s, FALSE);
