@@ -29,6 +29,7 @@
 
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
@@ -80,6 +81,7 @@ static GtkWidget *track_listview, *extract_button, *play_button;
 static GtkWidget *status_bar;
 static GtkWidget *extract_menuitem, *play_menuitem, *next_menuitem, *prev_menuitem, *select_all_menuitem, *deselect_all_menuitem;
 static GtkWidget *submit_menuitem;
+static GtkWidget *reread_menuitem;
 static GtkWidget *duplicate, *eject;
 GtkListStore *track_store;
 static BaconMessageConnection *connection;
@@ -87,7 +89,7 @@ GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 
 GtkWidget *current_message_area;
 
-const char *path_pattern, *file_pattern;
+char *path_pattern, *file_pattern;
 GFile *base_uri;
 BraseroDrive *drive = NULL;
 gboolean strip_chars;
@@ -305,7 +307,7 @@ static void number_cell_icon_data_cb (GtkTreeViewColumn *tree_column,
   gtk_tree_model_get (tree_model, iter, COLUMN_STATE, &state, -1);
   switch (state) {
   case STATE_IDLE:
-    g_object_set (G_OBJECT (cell), "stock-id", "", NULL);
+    g_object_set (G_OBJECT (cell), "stock-id", NULL, NULL);
     break;
   case STATE_PLAYING:
     g_object_set (G_OBJECT (cell), "stock-id", GTK_STOCK_MEDIA_PLAY, NULL);
@@ -341,7 +343,7 @@ set_info_bar_text_and_icon (GtkInfoBar  *infobar,
 
   ally_target = gtk_widget_get_accessible (button);
 
-  hbox_content = gtk_hbox_new (FALSE, 8);
+  hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8); 
   gtk_widget_show (hbox_content);
 
   image = gtk_image_new_from_stock (icon_stock_id, GTK_ICON_SIZE_DIALOG);
@@ -349,7 +351,7 @@ set_info_bar_text_and_icon (GtkInfoBar  *infobar,
   gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
   gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
 
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6); 
   gtk_widget_show (vbox);
   gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
 
@@ -836,6 +838,7 @@ metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
   if (current_submit_url) {
     gtk_widget_set_sensitive (submit_menuitem, TRUE);
   }
+  gtk_widget_set_sensitive (reread_menuitem, TRUE);
 
   /* Free old album details */
   if (current_album != NULL) {
@@ -901,6 +904,8 @@ static void reread_cd (gboolean ignore_no_media)
 
   window = gtk_widget_get_window (main_window);
 
+  gtk_widget_set_sensitive (reread_menuitem, FALSE);
+
   /* Make sure nothing is playing */
   stop_playback ();
 
@@ -908,7 +913,7 @@ static void reread_cd (gboolean ignore_no_media)
   if (realized) {
     cursor = gdk_cursor_new_for_display (gtk_widget_get_display (GTK_WIDGET (main_window)), GDK_WATCH);
     gdk_window_set_cursor (window, cursor);
-    gdk_cursor_unref (cursor);
+    g_object_unref (cursor);
     gdk_display_sync (gtk_widget_get_display (GTK_WIDGET (main_window)));
   }
 
@@ -1645,8 +1650,6 @@ int main (int argc, char **argv)
     { NULL }
   };
 
-  if (!g_thread_supported ()) g_thread_init (NULL);
-
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -1733,6 +1736,7 @@ int main (int argc, char **argv)
   select_all_menuitem   = GET_WIDGET ("select_all");
   deselect_all_menuitem = GET_WIDGET ("deselect_all");
   submit_menuitem       = GET_WIDGET ("submit");
+  reread_menuitem       = GET_WIDGET ("re-read");
   title_entry           = GET_WIDGET ("title_entry");
   artist_entry          = GET_WIDGET ("artist_entry");
   duration_label        = GET_WIDGET ("duration_label");
